@@ -2,6 +2,7 @@ existingOrganisms <- function(path, .type) {
     .files <- list.files(path)
     .files <- .files[!stringr::str_detect(.files, "doc_")]
     .files <- .files[!stringr::str_detect(.files, "md5cheksum")]
+    .files <- .files[!stringr::str_detect(.files, "documentation")]
     
     .orgs <- unlist(purrr::map(.files, function(x, type = .type) {
         .data <- unlist(stringr::str_split(x, "_"))
@@ -12,7 +13,7 @@ existingOrganisms <- function(path, .type) {
                 .data <- .data[-c(which_found:length(.data))]
                 return(paste0(.data, collapse = " "))
             } else {
-             warning("It seems like there are some files in download folder that are neither pre-downloaded species files nor doc_ or md5checksum files.", call. = FALSE)   
+             warning("It seems like there are some files in download folder that are neither pre-downloaded species files nor doc_, documentation, or md5checksum files.", call. = FALSE)   
             }
         }
     }))
