@@ -131,7 +131,6 @@ getCDS <-
                 }
             }
             
-            
             if (nrow(FoundOrganism) == 0) {
                 message(
                     paste0(
@@ -268,12 +267,11 @@ getCDS <-
                             
                         }, error = function(e)
                         {
-                            warning(
+                            message(
                                 "The download session seems to have timed out at the FTP site '",
                                 download_url, "'. This could be due to an overload of queries to the databases.",
                                 " Please restart this function to continue the data retrieval process or wait ",
-                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side.",
-                                call. = FALSE
+                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side."
                             )
                             return("Not available")
                         })
@@ -370,12 +368,11 @@ getCDS <-
                                              paste0(local.org, "_cds_from_genomic_", db, ".fna.gz")))
                     }
                 } else {
-                    stop(
+                    message(
                         "File: ",
                         download_url,
                         " could not be loaded properly... 
-                        Are you connected to the internet?",
-                        call. = FALSE
+                        Something went wrong with the internet connection."
                     )
                 }
             }
@@ -547,7 +544,6 @@ getCDS <-
                 } else {
                         return(cds.path[1])
                 }
-            
             }
         }
         
@@ -605,15 +601,14 @@ getCDS <-
                     ) 
                 
                 rest_url <- paste0(
-                    "http://rest.ensemblgenomes.org/info/assembly/",
+                    "http://rest.ensembl.org/info/assembly/",
                     new.organism,
                     "?content-type=application/json"
                 )
                 
                 if (curl::curl_fetch_memory(rest_url)$status_code != 200) {
-                    warning(
-                        "The url: '",rest_url,"' cannot be reached. This might be due to a connection issue or incorrect url path (e.g. not valid organism name).",
-                        call. = FALSE)
+                    message(
+                        "The url: '",rest_url,"' cannot be reached. This might be due to a connection issue or incorrect url path (e.g. not valid organism name).")
                     return(FALSE)
                 }
                 
@@ -718,7 +713,6 @@ getCDS <-
                         return(cds.path[1])
                 }
             }
-            
         }
     }
 
