@@ -280,12 +280,11 @@ getGenome <-
                    unlink(md5_file_path)         
             message("The md5 hash of file '", md5_file_path, "' matches!")
                         }, error = function(e) {
-                            warning(
+                            message(
                                 "The download session seems to have timed out at the FTP site '",
                                 download_url, "'. This could be due to an overload of queries to the databases.",
                                 " Please restart this function to continue the data retrieval process or wait ",
-                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side.",
-                                call. = FALSE
+                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side."
                             )
                             return("Not available")
                             })
@@ -388,12 +387,10 @@ getGenome <-
                                              )))
                     }
                 } else {
-                    stop(
-                        "File: ",
+                    message(
+                        "Something went wrong when trying to download file: ",
                         download_url,
-                        " could not be loaded properly... Are you connected to 
-                        the internet?",
-                        call. = FALSE
+                        " ... Sometimes the internet connection isn't stable and re-running the function might help. Otherwise, could there be an issue with the firewall?"
                     )
                 }
             }
@@ -620,7 +617,7 @@ getGenome <-
                     ) 
                 
                 url_api <- paste0(
-                    "http://rest.ensemblgenomes.org/info/assembly/",
+                    "http://rest.ensembl.org/info/assembly/",
                     new.organism,
                     "?content-type=application/json"
                 )
