@@ -1,4 +1,4 @@
-#' @title Retrieve available groups for a kingdom of life
+#' @title Retrieve available groups for a kingdom of life (only available for NCBI RefSeq and NCBI Genbank)
 #' @description A short list of available groups for a kingdom of life.
 #' @param db a character string specifying the database from which the genome 
 #' shall be retrieved: 
@@ -28,6 +28,10 @@
 #' @export
 
 getGroups <- function(db = "refseq", kingdom) {
+    
+    if (!is.element(db, c("refseq", "genbank")))
+        stop("Group information is unfortunately only available for db = 'refseq' and db = 'genbank'.", call. = FALSE)
+    
     groups <- listGroups(db = db, kingdom = kingdom, details = FALSE)
     return(names(groups))
 }
