@@ -275,12 +275,11 @@ getProteome <-
                 message("The md5 hash of file '", md5_file_path, "' matches!")
                             
                         }, error = function(e){
-                            warning(
+                            message(
                                 "The download session seems to have timed out at the FTP site '",
                                 download_url, "'. This could be due to an overload of queries to the databases.",
                                 " Please restart this function to continue the data retrieval process or wait ",
-                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side.",
-                                call. = FALSE
+                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side."
                             )
                             return("Not available")
                         })
@@ -371,12 +370,10 @@ getProteome <-
                     }
                     
                 } else {
-                    stop(
-                        "File: ",
+                    message(
+                        "Something went wrong when trying to download file: ",
                         download_url,
-                        " could not be loaded properly... Are you connected 
-                        to the internet?",
-                        call. = FALSE
+                        " ... Sometimes the internet connection isn't stable and re-running the function might help. Otherwise, could there be an issue with the firewall?"
                     )
                 }
             }
@@ -606,15 +603,14 @@ getProteome <-
                     ) 
                 
                 rest_url <- paste0(
-                    "http://rest.ensemblgenomes.org/info/assembly/",
+                    "http://rest.ensembl.org/info/assembly/",
                     new.organism,
                     "?content-type=application/json"
                 )
                 
                 if (curl::curl_fetch_memory(rest_url)$status_code != 200) {
-                    warning(
-                        "The url: '",rest_url,"' cannot be reached. This might be due to a connection issue or incorrect url path (e.g. not valid organism name).",
-                        call. = FALSE)
+                    message(
+                        "The url: '",rest_url,"' cannot be reached. This might be due to a connection issue or incorrect url path (e.g. not valid organism name).")
                         return(FALSE)
                 }
                 
@@ -726,9 +722,9 @@ getProteome <-
                         dir.create(path, recursive = TRUE)
                 }
                 
-                getUniProtSeq(organism = organism, path = path, update = TRUE)
+                getUniProtSeq(organism = organism, path = path, update = TRUE, gunzip = gunzip)
+                
         }
-
     }
 
 
