@@ -257,12 +257,11 @@ getRepeatMasker <-
                             
                         }, error = function(e)
                         {
-                            warning(
+                            message(
                                 "The download session seems to have timed out at the FTP site '",
                                 download_url, "'. This could be due to an overload of queries to the databases.",
                                 " Please restart this function to continue the data retrieval process or wait ",
-                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side.",
-                                call. = FALSE
+                                "for a while before restarting this function in case your IP address was logged due to an query overload on the server side."
                             )
                             return("Not available")
                         })
@@ -328,12 +327,10 @@ getRepeatMasker <-
                         paste0(local.org, "_rm_", db, ".out.gz")
                     ))
                 } else {
-                    stop(
-                        "File: ",
+                    message(
+                        "Something went wrong when trying to download file: ",
                         download_url,
-                        " could not be loaded properly... Are you connected to 
-                        the internet?",
-                        call. = FALSE
+                        " ... Sometimes the internet connection isn't stable and re-running the function might help. Otherwise, could there be an issue with the firewall?"
                     )
                 }
             }
