@@ -219,63 +219,3 @@ test_that("The getProteome() interface to Ensembl works properly using accession
 })
 
 
-test_that("The getProteome() interface to EnsemblGenomes works properly (including repeating command)..", {
-    skip_on_cran()
-    skip_on_travis()    
-        read_proteome(
-            getProteome(
-                db       = "ensemblgenomes",
-                organism = "Saccharomyces cerevisiae",
-                path     = tempdir()
-            ),
-            format = "fasta"
-        )
-        
-        read_proteome(
-            getProteome(
-                db       = "ensemblgenomes",
-                organism = "Saccharomyces cerevisiae",
-                path     = tempdir()
-            ),
-            format = "fasta"
-        )
-    
-})
-
-test_that("The getProteome() interface to EnsemblGenomes works properly using taxids..", {
-    skip_on_cran()
-    skip_on_travis()    
-    expect_error(read_proteome(
-        getProteome(
-            db       = "ensemblgenomes",
-            organism = "4932",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    ))
-    
-})
-
-test_that("The getProteome() interface to EnsemblGenomes works properly using accession ids..", {
-    skip_on_cran()
-    skip_on_travis()    
-    expect_error(read_proteome(
-        getProteome(
-            db       = "ensemblgenomes",
-            organism = "GCA_000976725.1",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    ))
-    
-})
-
-test_that("The getProteome() error messages work properly..", {
-    skip_on_cran()
-    skip_on_travis()     
-    expect_warning(getProteome(
-        db       = "ensembl",
-        organism = "Saccharomyces cerevisi",
-        path     = tempdir()
-    ))
-})
