@@ -217,65 +217,3 @@ test_that("The getRNA() interface to Ensembl works properly using accession id (
     )
 })
 
-test_that("The getRNA() interface to EnsemblGenomes works properly (including when command is repeated)..", {
-    skip_on_cran()
-    skip_on_travis()
-    # test proper download from ensemblgenomes
-    read_rna(
-        getRNA(
-            db       = "ensemblgenomes",
-            organism = "Saccharomyces cerevisiae",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    )
-    
-    read_rna(
-        getRNA(
-            db       = "ensemblgenomes",
-            organism = "Saccharomyces cerevisiae",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    )
-})
-
-test_that("The getRNA() interface to EnsemblGenomes works properly using taxid..", {
-    skip_on_cran()
-    skip_on_travis()
-    # test proper download from ensemblgenomes
-    expect_error(read_rna(
-        getRNA(
-            db       = "ensemblgenomes",
-            organism = "4932",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    ))
-    
-})
-
-
-test_that("The getRNA() interface to EnsemblGenomes works properly using accession id (including repeating command) ..", {
-    skip_on_cran()
-    skip_on_travis()
-    # test proper download from ensemblgenomes
-    read_rna(
-        getRNA(
-            db       = "ensemblgenomes",
-            organism = "GCA_000146045.2",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    )
-    
-    read_rna(
-        getRNA(
-            db       = "ensemblgenomes",
-            organism = "GCA_000146045.2",
-            path     = tempdir()
-        ),
-        format = "fasta"
-    )
-    
-})
